""" Cisco_IOS_XR_ip_rib_ipv6_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-rib\-ipv6 package operational data.

This module contains definitions
for the following management objects\:
  ipv6\-rib\: RIB operational data
  ipv6\-rib\-stdby\: ipv6 rib stdby

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError




class Ipv6Rib(object):
    """
    RIB operational data
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.rib_table_ids = Ipv6Rib.RibTableIds()
        self.rib_table_ids.parent = self
        self.vrfs = Ipv6Rib.Vrfs()
        self.vrfs.parent = self


    class RibTableIds(object):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.rib_table_id = YList()
            self.rib_table_id.parent = self
            self.rib_table_id.name = 'rib_table_id'


        class RibTableId(object):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.tableid = None
                self.rib_table_itf_hndls = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self.summary_protos = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self


            class SummaryProtos(object):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.summary_proto = YList()
                    self.summary_proto.parent = self
                    self.summary_proto.name = 'summary_proto'


                class SummaryProto(object):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.protoid = None
                        self.instance = None
                        self.name = None
                        self.proto_route_count = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self.rtype_bgp_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self.rtype_bgp_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self.rtype_bgp_loc = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self.rtype_igrp2_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self.rtype_igrp2_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self.rtype_isis_l1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self.rtype_isis_l1_ia = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self.rtype_isis_l2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self.rtype_isis_sum = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self.rtype_none = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self.rtype_ospf_extern1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self.rtype_ospf_extern2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self.rtype_ospf_inter = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self.rtype_ospf_intra = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self.rtype_ospf_nssa1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self.rtype_ospf_nssa2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self.rtype_other = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self


                    class ProtoRouteCount(object):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:proto-route-count'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount']['meta_info']


                    class RtypeNone(object):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-none'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone']['meta_info']


                    class RtypeOther(object):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-other'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther']['meta_info']


                    class RtypeOspfIntra(object):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-intra'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra']['meta_info']


                    class RtypeOspfInter(object):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-inter'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter']['meta_info']


                    class RtypeOspfExtern1(object):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-extern1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1']['meta_info']


                    class RtypeOspfExtern2(object):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-extern2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2']['meta_info']


                    class RtypeIsisSum(object):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-sum'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum']['meta_info']


                    class RtypeIsisL1(object):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1']['meta_info']


                    class RtypeIsisL2(object):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2']['meta_info']


                    class RtypeIsisL1Ia(object):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l1-ia'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia']['meta_info']


                    class RtypeBgpInt(object):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-int'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt']['meta_info']


                    class RtypeBgpExt(object):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-ext'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt']['meta_info']


                    class RtypeBgpLoc(object):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-loc'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc']['meta_info']


                    class RtypeOspfNssa1(object):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-nssa1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1']['meta_info']


                    class RtypeOspfNssa2(object):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-nssa2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2']['meta_info']


                    class RtypeIgrp2Int(object):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-igrp2-int'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int']['meta_info']


                    class RtypeIgrp2Ext(object):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-igrp2-ext'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.protoid is None:
                            raise YPYModelError('Key property protoid is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:summary-proto[Cisco-IOS-XR-ip-rib-ipv6-oper:protoid = ' + str(self.protoid) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.protoid is not None:
                            return True

                        if self.instance is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.proto_route_count is not None and self.proto_route_count._has_data():
                            return True

                        if self.rtype_bgp_ext is not None and self.rtype_bgp_ext._has_data():
                            return True

                        if self.rtype_bgp_int is not None and self.rtype_bgp_int._has_data():
                            return True

                        if self.rtype_bgp_loc is not None and self.rtype_bgp_loc._has_data():
                            return True

                        if self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext._has_data():
                            return True

                        if self.rtype_igrp2_int is not None and self.rtype_igrp2_int._has_data():
                            return True

                        if self.rtype_isis_l1 is not None and self.rtype_isis_l1._has_data():
                            return True

                        if self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia._has_data():
                            return True

                        if self.rtype_isis_l2 is not None and self.rtype_isis_l2._has_data():
                            return True

                        if self.rtype_isis_sum is not None and self.rtype_isis_sum._has_data():
                            return True

                        if self.rtype_none is not None and self.rtype_none._has_data():
                            return True

                        if self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1._has_data():
                            return True

                        if self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2._has_data():
                            return True

                        if self.rtype_ospf_inter is not None and self.rtype_ospf_inter._has_data():
                            return True

                        if self.rtype_ospf_intra is not None and self.rtype_ospf_intra._has_data():
                            return True

                        if self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1._has_data():
                            return True

                        if self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2._has_data():
                            return True

                        if self.rtype_other is not None and self.rtype_other._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:summary-protos'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.summary_proto is not None:
                        for child_ref in self.summary_proto:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.SummaryProtos']['meta_info']


            class RibTableItfHndls(object):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.rib_table_itf_hndl = YList()
                    self.rib_table_itf_hndl.parent = self
                    self.rib_table_itf_hndl.name = 'rib_table_itf_hndl'


                class RibTableItfHndl(object):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.handle = None
                        self.itf_route = YList()
                        self.itf_route.parent = self
                        self.itf_route.name = 'itf_route'


                    class ItfRoute(object):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.active = None
                            self.attribute_identity = None
                            self.client_id = None
                            self.distance = None
                            self.diversion = None
                            self.diversion_distance = None
                            self.diversion_proto_name = None
                            self.extended_flags = None
                            self.flags = None
                            self.flow_tag = None
                            self.fwd_class = None
                            self.instance = None
                            self.metric = None
                            self.paths_count = None
                            self.pic_count = None
                            self.prefix = None
                            self.prefix_length_xr = None
                            self.priority = None
                            self.protocol_id = None
                            self.protocol_name = None
                            self.qos_group = None
                            self.route_age = None
                            self.route_label = None
                            self.route_modify_time = None
                            self.route_path = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self.route_precedence = None
                            self.route_type = None
                            self.route_version = None
                            self.svd_type = None
                            self.tag = None
                            self.tbl_version = None
                            self.traffic_index = None
                            self.version = None


                        class RoutePath(object):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv6_rib_edm_path = YList()
                                self.ipv6_rib_edm_path.parent = self
                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                            class Ipv6RibEdmPath(object):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: labelstk
                                
                                	Labels for this path
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\:  list of str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.backup_pathid = None
                                    self.binding_label = None
                                    self.flags = None
                                    self.flags64 = None
                                    self.has_labelstk = None
                                    self.information_source = None
                                    self.interface_name = None
                                    self.labelstk = YLeafList()
                                    self.labelstk.parent = self
                                    self.labelstk.name = 'labelstk'
                                    self.load_metric = None
                                    self.looped = None
                                    self.metric = None
                                    self.mpls_feid = None
                                    self.mvpn_present = None
                                    self.next_hop_afi = None
                                    self.next_hop_id = None
                                    self.next_hop_id_refcount = None
                                    self.next_hop_safi = None
                                    self.next_hop_table_id = None
                                    self.next_hop_table_name = None
                                    self.next_hop_vrf_name = None
                                    self.nhid_feid = None
                                    self.num_labels = None
                                    self.number_of_extended_communities = None
                                    self.ospf_area_id = None
                                    self.path_rt_present = None
                                    self.pathid = None
                                    self.private_flags = None
                                    self.ref_cnt_of_backup = None
                                    self.remote_backup_addr = YLeafList()
                                    self.remote_backup_addr.parent = self
                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                    self.route_label = None
                                    self.segmented_nexthop_present = None
                                    self.source_asrt_present = None
                                    self.source_rd_present = None
                                    self.tunnel_id = None
                                    self.v6_information_source = None
                                    self.v6_nexthop = None
                                    self.vrf_import_rt_present = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.backup_pathid is not None:
                                        return True

                                    if self.binding_label is not None:
                                        return True

                                    if self.flags is not None:
                                        return True

                                    if self.flags64 is not None:
                                        return True

                                    if self.has_labelstk is not None:
                                        return True

                                    if self.information_source is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.labelstk is not None:
                                        for child in self.labelstk:
                                            if child is not None:
                                                return True

                                    if self.load_metric is not None:
                                        return True

                                    if self.looped is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.mpls_feid is not None:
                                        return True

                                    if self.mvpn_present is not None:
                                        return True

                                    if self.next_hop_afi is not None:
                                        return True

                                    if self.next_hop_id is not None:
                                        return True

                                    if self.next_hop_id_refcount is not None:
                                        return True

                                    if self.next_hop_safi is not None:
                                        return True

                                    if self.next_hop_table_id is not None:
                                        return True

                                    if self.next_hop_table_name is not None:
                                        return True

                                    if self.next_hop_vrf_name is not None:
                                        return True

                                    if self.nhid_feid is not None:
                                        return True

                                    if self.num_labels is not None:
                                        return True

                                    if self.number_of_extended_communities is not None:
                                        return True

                                    if self.ospf_area_id is not None:
                                        return True

                                    if self.path_rt_present is not None:
                                        return True

                                    if self.pathid is not None:
                                        return True

                                    if self.private_flags is not None:
                                        return True

                                    if self.ref_cnt_of_backup is not None:
                                        return True

                                    if self.remote_backup_addr is not None:
                                        for child in self.remote_backup_addr:
                                            if child is not None:
                                                return True

                                    if self.route_label is not None:
                                        return True

                                    if self.segmented_nexthop_present is not None:
                                        return True

                                    if self.source_asrt_present is not None:
                                        return True

                                    if self.source_rd_present is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    if self.v6_information_source is not None:
                                        return True

                                    if self.v6_nexthop is not None:
                                        return True

                                    if self.vrf_import_rt_present is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                    return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv6_rib_edm_path is not None:
                                    for child_ref in self.ipv6_rib_edm_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.address is None:
                                raise YPYModelError('Key property address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:itf-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.active is not None:
                                return True

                            if self.attribute_identity is not None:
                                return True

                            if self.client_id is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.diversion is not None:
                                return True

                            if self.diversion_distance is not None:
                                return True

                            if self.diversion_proto_name is not None:
                                return True

                            if self.extended_flags is not None:
                                return True

                            if self.flags is not None:
                                return True

                            if self.flow_tag is not None:
                                return True

                            if self.fwd_class is not None:
                                return True

                            if self.instance is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.paths_count is not None:
                                return True

                            if self.pic_count is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol_id is not None:
                                return True

                            if self.protocol_name is not None:
                                return True

                            if self.qos_group is not None:
                                return True

                            if self.route_age is not None:
                                return True

                            if self.route_label is not None:
                                return True

                            if self.route_modify_time is not None:
                                return True

                            if self.route_path is not None and self.route_path._has_data():
                                return True

                            if self.route_precedence is not None:
                                return True

                            if self.route_type is not None:
                                return True

                            if self.route_version is not None:
                                return True

                            if self.svd_type is not None:
                                return True

                            if self.tag is not None:
                                return True

                            if self.tbl_version is not None:
                                return True

                            if self.traffic_index is not None:
                                return True

                            if self.version is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.handle is None:
                            raise YPYModelError('Key property handle is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-itf-hndl[Cisco-IOS-XR-ip-rib-ipv6-oper:handle = ' + str(self.handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.handle is not None:
                            return True

                        if self.itf_route is not None:
                            for child_ref in self.itf_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-itf-hndls'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.rib_table_itf_hndl is not None:
                        for child_ref in self.rib_table_itf_hndl:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls']['meta_info']

            @property
            def _common_path(self):
                if self.tableid is None:
                    raise YPYModelError('Key property tableid is None')

                return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-ids/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-id[Cisco-IOS-XR-ip-rib-ipv6-oper:tableid = ' + str(self.tableid) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.tableid is not None:
                    return True

                if self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls._has_data():
                    return True

                if self.summary_protos is not None and self.summary_protos._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                return meta._meta_table['Ipv6Rib.RibTableIds.RibTableId']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-ids'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.rib_table_id is not None:
                for child_ref in self.rib_table_id:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
            return meta._meta_table['Ipv6Rib.RibTableIds']['meta_info']


    class Vrfs(object):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.vrf = YList()
            self.vrf.parent = self
            self.vrf.name = 'vrf'


        class Vrf(object):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf_name = None
                self.afs = Ipv6Rib.Vrfs.Vrf.Afs()
                self.afs.parent = self


            class Afs(object):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.af = YList()
                    self.af.parent = self
                    self.af.name = 'af'


                class Af(object):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.safs = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self


                    class Safs(object):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.saf = YList()
                            self.saf.parent = self
                            self.saf.name = 'saf'


                        class Saf(object):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.saf_name = None
                                self.ip_rib_route_table_names = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self


                            class IpRibRouteTableNames(object):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_rib_route_table_name = YList()
                                    self.ip_rib_route_table_name.parent = self
                                    self.ip_rib_route_table_name.name = 'ip_rib_route_table_name'


                                class IpRibRouteTableName(object):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table 
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.route_table_name = None
                                        self.adverts = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self.backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self.deleted_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self.destination_kw = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self.protocol = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self.q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self.routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self


                                    class DestinationKw(object):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dest_backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self.dest_best_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self.dest_next_hop_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self.dest_q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self


                                        class DestQRoutes(object):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_q_route = YList()
                                                self.dest_q_route.parent = self
                                                self.dest_q_route.name = 'dest_q_route'


                                            class DestQRoute(object):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.active = None
                                                    self.address = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-q-route'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.active is not None:
                                                        return True

                                                    if self.address is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-q-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_q_route is not None:
                                                    for child_ref in self.dest_q_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes']['meta_info']


                                        class DestBackupRoutes(object):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_backup_route = YList()
                                                self.dest_backup_route.parent = self
                                                self.dest_backup_route.name = 'dest_backup_route'


                                            class DestBackupRoute(object):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.active = None
                                                    self.address = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-backup-route'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.active is not None:
                                                        return True

                                                    if self.address is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-backup-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_backup_route is not None:
                                                    for child_ref in self.dest_backup_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes']['meta_info']


                                        class DestBestRoutes(object):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_best_route = YList()
                                                self.dest_best_route.parent = self
                                                self.dest_best_route.name = 'dest_best_route'


                                            class DestBestRoute(object):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.address = None
                                                    self.active = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.address is None:
                                                        raise YPYModelError('Key property address is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-best-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.address is not None:
                                                        return True

                                                    if self.active is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-best-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_best_route is not None:
                                                    for child_ref in self.dest_best_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes']['meta_info']


                                        class DestNextHopRoutes(object):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_next_hop_route = YList()
                                                self.dest_next_hop_route.parent = self
                                                self.dest_next_hop_route.name = 'dest_next_hop_route'


                                            class DestNextHopRoute(object):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.address = None
                                                    self.active = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.address is None:
                                                        raise YPYModelError('Key property address is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-next-hop-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.address is not None:
                                                        return True

                                                    if self.active is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-next-hop-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_next_hop_route is not None:
                                                    for child_ref in self.dest_next_hop_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:destination-kw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dest_backup_routes is not None and self.dest_backup_routes._has_data():
                                                return True

                                            if self.dest_best_routes is not None and self.dest_best_routes._has_data():
                                                return True

                                            if self.dest_next_hop_routes is not None and self.dest_next_hop_routes._has_data():
                                                return True

                                            if self.dest_q_routes is not None and self.dest_q_routes._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw']['meta_info']


                                    class Adverts(object):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advert = YList()
                                            self.advert.parent = self
                                            self.advert.name = 'advert'


                                        class Advert(object):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.address = None
                                                self.ipv6_rib_edm_advert = YList()
                                                self.ipv6_rib_edm_advert.parent = self
                                                self.ipv6_rib_edm_advert.name = 'ipv6_rib_edm_advert'
                                                self.prefix_length = None


                                            class Ipv6RibEdmAdvert(object):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.client_id = None
                                                    self.code = None
                                                    self.extended_communities = None
                                                    self.instance_name = None
                                                    self.number_of_extended_communities = None
                                                    self.protocol_id = None
                                                    self.protocol_opaque = None
                                                    self.protocol_opaque_flags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-advert'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.client_id is not None:
                                                        return True

                                                    if self.code is not None:
                                                        return True

                                                    if self.extended_communities is not None:
                                                        return True

                                                    if self.instance_name is not None:
                                                        return True

                                                    if self.number_of_extended_communities is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_opaque is not None:
                                                        return True

                                                    if self.protocol_opaque_flags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:advert'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address is not None:
                                                    return True

                                                if self.ipv6_rib_edm_advert is not None:
                                                    for child_ref in self.ipv6_rib_edm_advert:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:adverts'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advert is not None:
                                                for child_ref in self.advert:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts']['meta_info']


                                    class DeletedRoutes(object):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.deleted_route = YList()
                                            self.deleted_route.parent = self
                                            self.deleted_route.name = 'deleted_route'


                                        class DeletedRoute(object):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:deleted-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:deleted-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.deleted_route is not None:
                                                for child_ref in self.deleted_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes']['meta_info']


                                    class Protocol(object):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self.connected = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self.eigrp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self.isis = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self.local = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self.mobile = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self.ospf = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self.rpl = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self.static = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self.subscriber = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self.te_client = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self


                                        class Local(object):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lspv = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self


                                            class Lspv(object):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:lspv'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv']['meta_info']


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lspv is not None and self.lspv._has_data():
                                                    return True

                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local']['meta_info']


                                        class Bgp(object):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:bgp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp']['meta_info']


                                        class Mobile(object):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:mobile'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile']['meta_info']


                                        class Eigrp(object):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:eigrp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp']['meta_info']


                                        class Rpl(object):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rpl'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl']['meta_info']


                                        class Static(object):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:static'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static']['meta_info']


                                        class TeClient(object):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:te-client'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient']['meta_info']


                                        class Subscriber(object):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:subscriber'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber']['meta_info']


                                        class Ospf(object):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ospf'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf']['meta_info']


                                        class Connected(object):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:   :py:class:`L2Vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                self.l2vpn.parent = self
                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self


                                            class L2Vpn(object):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:l2vpn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn']['meta_info']


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:connected'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn is not None and self.l2vpn._has_data():
                                                    return True

                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected']['meta_info']


                                        class Isis(object):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:isis'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp is not None and self.bgp._has_data():
                                                return True

                                            if self.connected is not None and self.connected._has_data():
                                                return True

                                            if self.eigrp is not None and self.eigrp._has_data():
                                                return True

                                            if self.isis is not None and self.isis._has_data():
                                                return True

                                            if self.local is not None and self.local._has_data():
                                                return True

                                            if self.mobile is not None and self.mobile._has_data():
                                                return True

                                            if self.ospf is not None and self.ospf._has_data():
                                                return True

                                            if self.rpl is not None and self.rpl._has_data():
                                                return True

                                            if self.static is not None and self.static._has_data():
                                                return True

                                            if self.subscriber is not None and self.subscriber._has_data():
                                                return True

                                            if self.te_client is not None and self.te_client._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol']['meta_info']


                                    class Routes(object):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.route = YList()
                                            self.route.parent = self
                                            self.route.name = 'route'


                                        class Route(object):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.interface_name = None
                                                self.metric = None
                                                self.next_hop_address = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.interface_name is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.next_hop_address is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.route is not None:
                                                for child_ref in self.route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes']['meta_info']


                                    class QRoutes(object):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.q_route = YList()
                                            self.q_route.parent = self
                                            self.q_route.name = 'q_route'


                                        class QRoute(object):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:q-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:q-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.q_route is not None:
                                                for child_ref in self.q_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes']['meta_info']


                                    class BackupRoutes(object):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.backup_route = YList()
                                            self.backup_route.parent = self
                                            self.backup_route.name = 'backup_route'


                                        class BackupRoute(object):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.protoid = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:backup-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.protoid is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:backup-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.backup_route is not None:
                                                for child_ref in self.backup_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.route_table_name is None:
                                            raise YPYModelError('Key property route_table_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ip-rib-route-table-name[Cisco-IOS-XR-ip-rib-ipv6-oper:route-table-name = ' + str(self.route_table_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.route_table_name is not None:
                                            return True

                                        if self.adverts is not None and self.adverts._has_data():
                                            return True

                                        if self.backup_routes is not None and self.backup_routes._has_data():
                                            return True

                                        if self.deleted_routes is not None and self.deleted_routes._has_data():
                                            return True

                                        if self.destination_kw is not None and self.destination_kw._has_data():
                                            return True

                                        if self.protocol is not None and self.protocol._has_data():
                                            return True

                                        if self.q_routes is not None and self.q_routes._has_data():
                                            return True

                                        if self.routes is not None and self.routes._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ip-rib-route-table-names'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_rib_route_table_name is not None:
                                        for child_ref in self.ip_rib_route_table_name:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.saf_name is None:
                                    raise YPYModelError('Key property saf_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:saf[Cisco-IOS-XR-ip-rib-ipv6-oper:saf-name = ' + str(self.saf_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.saf_name is not None:
                                    return True

                                if self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:safs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.saf is not None:
                                for child_ref in self.saf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.af_name is None:
                            raise YPYModelError('Key property af_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:af[Cisco-IOS-XR-ip-rib-ipv6-oper:af-name = ' + str(self.af_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.safs is not None and self.safs._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs.Af']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.af is not None:
                        for child_ref in self.af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6Rib.Vrfs.Vrf.Afs']['meta_info']

            @property
            def _common_path(self):
                if self.vrf_name is None:
                    raise YPYModelError('Key property vrf_name is None')

                return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/Cisco-IOS-XR-ip-rib-ipv6-oper:vrfs/Cisco-IOS-XR-ip-rib-ipv6-oper:vrf[Cisco-IOS-XR-ip-rib-ipv6-oper:vrf-name = ' + str(self.vrf_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf_name is not None:
                    return True

                if self.afs is not None and self.afs._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                return meta._meta_table['Ipv6Rib.Vrfs.Vrf']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/Cisco-IOS-XR-ip-rib-ipv6-oper:vrfs'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.vrf is not None:
                for child_ref in self.vrf:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
            return meta._meta_table['Ipv6Rib.Vrfs']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.rib_table_ids is not None and self.rib_table_ids._has_data():
            return True

        if self.vrfs is not None and self.vrfs._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
        return meta._meta_table['Ipv6Rib']['meta_info']


class Ipv6RibStdby(object):
    """
    ipv6 rib stdby
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.rib_table_ids = Ipv6RibStdby.RibTableIds()
        self.rib_table_ids.parent = self
        self.vrfs = Ipv6RibStdby.Vrfs()
        self.vrfs.parent = self


    class RibTableIds(object):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.rib_table_id = YList()
            self.rib_table_id.parent = self
            self.rib_table_id.name = 'rib_table_id'


        class RibTableId(object):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.tableid = None
                self.rib_table_itf_hndls = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self.summary_protos = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self


            class SummaryProtos(object):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.summary_proto = YList()
                    self.summary_proto.parent = self
                    self.summary_proto.name = 'summary_proto'


                class SummaryProto(object):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.protoid = None
                        self.instance = None
                        self.name = None
                        self.proto_route_count = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self.rtype_bgp_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self.rtype_bgp_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self.rtype_bgp_loc = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self.rtype_igrp2_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self.rtype_igrp2_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self.rtype_isis_l1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self.rtype_isis_l1_ia = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self.rtype_isis_l2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self.rtype_isis_sum = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self.rtype_none = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self.rtype_ospf_extern1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self.rtype_ospf_extern2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self.rtype_ospf_inter = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self.rtype_ospf_intra = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self.rtype_ospf_nssa1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self.rtype_ospf_nssa2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self.rtype_other = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self


                    class ProtoRouteCount(object):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:proto-route-count'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount']['meta_info']


                    class RtypeNone(object):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-none'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone']['meta_info']


                    class RtypeOther(object):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-other'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther']['meta_info']


                    class RtypeOspfIntra(object):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-intra'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra']['meta_info']


                    class RtypeOspfInter(object):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-inter'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter']['meta_info']


                    class RtypeOspfExtern1(object):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-extern1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1']['meta_info']


                    class RtypeOspfExtern2(object):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-extern2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2']['meta_info']


                    class RtypeIsisSum(object):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-sum'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum']['meta_info']


                    class RtypeIsisL1(object):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1']['meta_info']


                    class RtypeIsisL2(object):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2']['meta_info']


                    class RtypeIsisL1Ia(object):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-isis-l1-ia'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia']['meta_info']


                    class RtypeBgpInt(object):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-int'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt']['meta_info']


                    class RtypeBgpExt(object):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-ext'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt']['meta_info']


                    class RtypeBgpLoc(object):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-bgp-loc'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc']['meta_info']


                    class RtypeOspfNssa1(object):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-nssa1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1']['meta_info']


                    class RtypeOspfNssa2(object):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-ospf-nssa2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2']['meta_info']


                    class RtypeIgrp2Int(object):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-igrp2-int'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int']['meta_info']


                    class RtypeIgrp2Ext(object):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active_routes_count = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self.num_backup_routes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rtype-igrp2-ext'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active_routes_count is not None:
                                return True

                            if self.num_active_paths is not None:
                                return True

                            if self.num_backup_paths is not None:
                                return True

                            if self.num_backup_routes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.protoid is None:
                            raise YPYModelError('Key property protoid is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:summary-proto[Cisco-IOS-XR-ip-rib-ipv6-oper:protoid = ' + str(self.protoid) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.protoid is not None:
                            return True

                        if self.instance is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.proto_route_count is not None and self.proto_route_count._has_data():
                            return True

                        if self.rtype_bgp_ext is not None and self.rtype_bgp_ext._has_data():
                            return True

                        if self.rtype_bgp_int is not None and self.rtype_bgp_int._has_data():
                            return True

                        if self.rtype_bgp_loc is not None and self.rtype_bgp_loc._has_data():
                            return True

                        if self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext._has_data():
                            return True

                        if self.rtype_igrp2_int is not None and self.rtype_igrp2_int._has_data():
                            return True

                        if self.rtype_isis_l1 is not None and self.rtype_isis_l1._has_data():
                            return True

                        if self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia._has_data():
                            return True

                        if self.rtype_isis_l2 is not None and self.rtype_isis_l2._has_data():
                            return True

                        if self.rtype_isis_sum is not None and self.rtype_isis_sum._has_data():
                            return True

                        if self.rtype_none is not None and self.rtype_none._has_data():
                            return True

                        if self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1._has_data():
                            return True

                        if self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2._has_data():
                            return True

                        if self.rtype_ospf_inter is not None and self.rtype_ospf_inter._has_data():
                            return True

                        if self.rtype_ospf_intra is not None and self.rtype_ospf_intra._has_data():
                            return True

                        if self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1._has_data():
                            return True

                        if self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2._has_data():
                            return True

                        if self.rtype_other is not None and self.rtype_other._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:summary-protos'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.summary_proto is not None:
                        for child_ref in self.summary_proto:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos']['meta_info']


            class RibTableItfHndls(object):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.rib_table_itf_hndl = YList()
                    self.rib_table_itf_hndl.parent = self
                    self.rib_table_itf_hndl.name = 'rib_table_itf_hndl'


                class RibTableItfHndl(object):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.handle = None
                        self.itf_route = YList()
                        self.itf_route.parent = self
                        self.itf_route.name = 'itf_route'


                    class ItfRoute(object):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.active = None
                            self.attribute_identity = None
                            self.client_id = None
                            self.distance = None
                            self.diversion = None
                            self.diversion_distance = None
                            self.diversion_proto_name = None
                            self.extended_flags = None
                            self.flags = None
                            self.flow_tag = None
                            self.fwd_class = None
                            self.instance = None
                            self.metric = None
                            self.paths_count = None
                            self.pic_count = None
                            self.prefix = None
                            self.prefix_length_xr = None
                            self.priority = None
                            self.protocol_id = None
                            self.protocol_name = None
                            self.qos_group = None
                            self.route_age = None
                            self.route_label = None
                            self.route_modify_time = None
                            self.route_path = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self.route_precedence = None
                            self.route_type = None
                            self.route_version = None
                            self.svd_type = None
                            self.tag = None
                            self.tbl_version = None
                            self.traffic_index = None
                            self.version = None


                        class RoutePath(object):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv6_rib_edm_path = YList()
                                self.ipv6_rib_edm_path.parent = self
                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                            class Ipv6RibEdmPath(object):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: labelstk
                                
                                	Labels for this path
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\:  list of str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.backup_pathid = None
                                    self.binding_label = None
                                    self.flags = None
                                    self.flags64 = None
                                    self.has_labelstk = None
                                    self.information_source = None
                                    self.interface_name = None
                                    self.labelstk = YLeafList()
                                    self.labelstk.parent = self
                                    self.labelstk.name = 'labelstk'
                                    self.load_metric = None
                                    self.looped = None
                                    self.metric = None
                                    self.mpls_feid = None
                                    self.mvpn_present = None
                                    self.next_hop_afi = None
                                    self.next_hop_id = None
                                    self.next_hop_id_refcount = None
                                    self.next_hop_safi = None
                                    self.next_hop_table_id = None
                                    self.next_hop_table_name = None
                                    self.next_hop_vrf_name = None
                                    self.nhid_feid = None
                                    self.num_labels = None
                                    self.number_of_extended_communities = None
                                    self.ospf_area_id = None
                                    self.path_rt_present = None
                                    self.pathid = None
                                    self.private_flags = None
                                    self.ref_cnt_of_backup = None
                                    self.remote_backup_addr = YLeafList()
                                    self.remote_backup_addr.parent = self
                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                    self.route_label = None
                                    self.segmented_nexthop_present = None
                                    self.source_asrt_present = None
                                    self.source_rd_present = None
                                    self.tunnel_id = None
                                    self.v6_information_source = None
                                    self.v6_nexthop = None
                                    self.vrf_import_rt_present = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.backup_pathid is not None:
                                        return True

                                    if self.binding_label is not None:
                                        return True

                                    if self.flags is not None:
                                        return True

                                    if self.flags64 is not None:
                                        return True

                                    if self.has_labelstk is not None:
                                        return True

                                    if self.information_source is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.labelstk is not None:
                                        for child in self.labelstk:
                                            if child is not None:
                                                return True

                                    if self.load_metric is not None:
                                        return True

                                    if self.looped is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.mpls_feid is not None:
                                        return True

                                    if self.mvpn_present is not None:
                                        return True

                                    if self.next_hop_afi is not None:
                                        return True

                                    if self.next_hop_id is not None:
                                        return True

                                    if self.next_hop_id_refcount is not None:
                                        return True

                                    if self.next_hop_safi is not None:
                                        return True

                                    if self.next_hop_table_id is not None:
                                        return True

                                    if self.next_hop_table_name is not None:
                                        return True

                                    if self.next_hop_vrf_name is not None:
                                        return True

                                    if self.nhid_feid is not None:
                                        return True

                                    if self.num_labels is not None:
                                        return True

                                    if self.number_of_extended_communities is not None:
                                        return True

                                    if self.ospf_area_id is not None:
                                        return True

                                    if self.path_rt_present is not None:
                                        return True

                                    if self.pathid is not None:
                                        return True

                                    if self.private_flags is not None:
                                        return True

                                    if self.ref_cnt_of_backup is not None:
                                        return True

                                    if self.remote_backup_addr is not None:
                                        for child in self.remote_backup_addr:
                                            if child is not None:
                                                return True

                                    if self.route_label is not None:
                                        return True

                                    if self.segmented_nexthop_present is not None:
                                        return True

                                    if self.source_asrt_present is not None:
                                        return True

                                    if self.source_rd_present is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    if self.v6_information_source is not None:
                                        return True

                                    if self.v6_nexthop is not None:
                                        return True

                                    if self.vrf_import_rt_present is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                    return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv6_rib_edm_path is not None:
                                    for child_ref in self.ipv6_rib_edm_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.address is None:
                                raise YPYModelError('Key property address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:itf-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.active is not None:
                                return True

                            if self.attribute_identity is not None:
                                return True

                            if self.client_id is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.diversion is not None:
                                return True

                            if self.diversion_distance is not None:
                                return True

                            if self.diversion_proto_name is not None:
                                return True

                            if self.extended_flags is not None:
                                return True

                            if self.flags is not None:
                                return True

                            if self.flow_tag is not None:
                                return True

                            if self.fwd_class is not None:
                                return True

                            if self.instance is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.paths_count is not None:
                                return True

                            if self.pic_count is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol_id is not None:
                                return True

                            if self.protocol_name is not None:
                                return True

                            if self.qos_group is not None:
                                return True

                            if self.route_age is not None:
                                return True

                            if self.route_label is not None:
                                return True

                            if self.route_modify_time is not None:
                                return True

                            if self.route_path is not None and self.route_path._has_data():
                                return True

                            if self.route_precedence is not None:
                                return True

                            if self.route_type is not None:
                                return True

                            if self.route_version is not None:
                                return True

                            if self.svd_type is not None:
                                return True

                            if self.tag is not None:
                                return True

                            if self.tbl_version is not None:
                                return True

                            if self.traffic_index is not None:
                                return True

                            if self.version is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.handle is None:
                            raise YPYModelError('Key property handle is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-itf-hndl[Cisco-IOS-XR-ip-rib-ipv6-oper:handle = ' + str(self.handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.handle is not None:
                            return True

                        if self.itf_route is not None:
                            for child_ref in self.itf_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-itf-hndls'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.rib_table_itf_hndl is not None:
                        for child_ref in self.rib_table_itf_hndl:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls']['meta_info']

            @property
            def _common_path(self):
                if self.tableid is None:
                    raise YPYModelError('Key property tableid is None')

                return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-ids/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-id[Cisco-IOS-XR-ip-rib-ipv6-oper:tableid = ' + str(self.tableid) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.tableid is not None:
                    return True

                if self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls._has_data():
                    return True

                if self.summary_protos is not None and self.summary_protos._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                return meta._meta_table['Ipv6RibStdby.RibTableIds.RibTableId']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/Cisco-IOS-XR-ip-rib-ipv6-oper:rib-table-ids'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.rib_table_id is not None:
                for child_ref in self.rib_table_id:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
            return meta._meta_table['Ipv6RibStdby.RibTableIds']['meta_info']


    class Vrfs(object):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.vrf = YList()
            self.vrf.parent = self
            self.vrf.name = 'vrf'


        class Vrf(object):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf_name = None
                self.afs = Ipv6RibStdby.Vrfs.Vrf.Afs()
                self.afs.parent = self


            class Afs(object):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.af = YList()
                    self.af.parent = self
                    self.af.name = 'af'


                class Af(object):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.safs = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self


                    class Safs(object):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.saf = YList()
                            self.saf.parent = self
                            self.saf.name = 'saf'


                        class Saf(object):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.saf_name = None
                                self.ip_rib_route_table_names = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self


                            class IpRibRouteTableNames(object):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_rib_route_table_name = YList()
                                    self.ip_rib_route_table_name.parent = self
                                    self.ip_rib_route_table_name.name = 'ip_rib_route_table_name'


                                class IpRibRouteTableName(object):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table 
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.route_table_name = None
                                        self.adverts = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self.backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self.deleted_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self.destination_kw = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self.protocol = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self.q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self.routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self


                                    class DestinationKw(object):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dest_backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self.dest_best_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self.dest_next_hop_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self.dest_q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self


                                        class DestQRoutes(object):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_q_route = YList()
                                                self.dest_q_route.parent = self
                                                self.dest_q_route.name = 'dest_q_route'


                                            class DestQRoute(object):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.active = None
                                                    self.address = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-q-route'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.active is not None:
                                                        return True

                                                    if self.address is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-q-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_q_route is not None:
                                                    for child_ref in self.dest_q_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes']['meta_info']


                                        class DestBackupRoutes(object):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_backup_route = YList()
                                                self.dest_backup_route.parent = self
                                                self.dest_backup_route.name = 'dest_backup_route'


                                            class DestBackupRoute(object):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.active = None
                                                    self.address = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-backup-route'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.active is not None:
                                                        return True

                                                    if self.address is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-backup-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_backup_route is not None:
                                                    for child_ref in self.dest_backup_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes']['meta_info']


                                        class DestBestRoutes(object):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_best_route = YList()
                                                self.dest_best_route.parent = self
                                                self.dest_best_route.name = 'dest_best_route'


                                            class DestBestRoute(object):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.address = None
                                                    self.active = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.address is None:
                                                        raise YPYModelError('Key property address is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-best-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.address is not None:
                                                        return True

                                                    if self.active is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-best-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_best_route is not None:
                                                    for child_ref in self.dest_best_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes']['meta_info']


                                        class DestNextHopRoutes(object):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dest_next_hop_route = YList()
                                                self.dest_next_hop_route.parent = self
                                                self.dest_next_hop_route.name = 'dest_next_hop_route'


                                            class DestNextHopRoute(object):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.address = None
                                                    self.active = None
                                                    self.attribute_identity = None
                                                    self.client_id = None
                                                    self.distance = None
                                                    self.diversion = None
                                                    self.diversion_distance = None
                                                    self.diversion_proto_name = None
                                                    self.extended_flags = None
                                                    self.flags = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.instance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.pic_count = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.priority = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.qos_group = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.route_modify_time = None
                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self.route_precedence = None
                                                    self.route_type = None
                                                    self.route_version = None
                                                    self.svd_type = None
                                                    self.tag = None
                                                    self.tbl_version = None
                                                    self.traffic_index = None
                                                    self.version = None


                                                class RoutePath(object):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_rib_edm_path = YList()
                                                        self.ipv6_rib_edm_path.parent = self
                                                        self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                    class Ipv6RibEdmPath(object):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.address = None
                                                            self.backup_pathid = None
                                                            self.binding_label = None
                                                            self.flags = None
                                                            self.flags64 = None
                                                            self.has_labelstk = None
                                                            self.information_source = None
                                                            self.interface_name = None
                                                            self.labelstk = YLeafList()
                                                            self.labelstk.parent = self
                                                            self.labelstk.name = 'labelstk'
                                                            self.load_metric = None
                                                            self.looped = None
                                                            self.metric = None
                                                            self.mpls_feid = None
                                                            self.mvpn_present = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.next_hop_safi = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_vrf_name = None
                                                            self.nhid_feid = None
                                                            self.num_labels = None
                                                            self.number_of_extended_communities = None
                                                            self.ospf_area_id = None
                                                            self.path_rt_present = None
                                                            self.pathid = None
                                                            self.private_flags = None
                                                            self.ref_cnt_of_backup = None
                                                            self.remote_backup_addr = YLeafList()
                                                            self.remote_backup_addr.parent = self
                                                            self.remote_backup_addr.name = 'remote_backup_addr'
                                                            self.route_label = None
                                                            self.segmented_nexthop_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.tunnel_id = None
                                                            self.v6_information_source = None
                                                            self.v6_nexthop = None
                                                            self.vrf_import_rt_present = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.address is not None:
                                                                return True

                                                            if self.backup_pathid is not None:
                                                                return True

                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flags64 is not None:
                                                                return True

                                                            if self.has_labelstk is not None:
                                                                return True

                                                            if self.information_source is not None:
                                                                return True

                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.labelstk is not None:
                                                                for child in self.labelstk:
                                                                    if child is not None:
                                                                        return True

                                                            if self.load_metric is not None:
                                                                return True

                                                            if self.looped is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.mpls_feid is not None:
                                                                return True

                                                            if self.mvpn_present is not None:
                                                                return True

                                                            if self.next_hop_afi is not None:
                                                                return True

                                                            if self.next_hop_id is not None:
                                                                return True

                                                            if self.next_hop_id_refcount is not None:
                                                                return True

                                                            if self.next_hop_safi is not None:
                                                                return True

                                                            if self.next_hop_table_id is not None:
                                                                return True

                                                            if self.next_hop_table_name is not None:
                                                                return True

                                                            if self.next_hop_vrf_name is not None:
                                                                return True

                                                            if self.nhid_feid is not None:
                                                                return True

                                                            if self.num_labels is not None:
                                                                return True

                                                            if self.number_of_extended_communities is not None:
                                                                return True

                                                            if self.ospf_area_id is not None:
                                                                return True

                                                            if self.path_rt_present is not None:
                                                                return True

                                                            if self.pathid is not None:
                                                                return True

                                                            if self.private_flags is not None:
                                                                return True

                                                            if self.ref_cnt_of_backup is not None:
                                                                return True

                                                            if self.remote_backup_addr is not None:
                                                                for child in self.remote_backup_addr:
                                                                    if child is not None:
                                                                        return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.segmented_nexthop_present is not None:
                                                                return True

                                                            if self.source_asrt_present is not None:
                                                                return True

                                                            if self.source_rd_present is not None:
                                                                return True

                                                            if self.tunnel_id is not None:
                                                                return True

                                                            if self.v6_information_source is not None:
                                                                return True

                                                            if self.v6_nexthop is not None:
                                                                return True

                                                            if self.vrf_import_rt_present is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_rib_edm_path is not None:
                                                            for child_ref in self.ipv6_rib_edm_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.address is None:
                                                        raise YPYModelError('Key property address is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-next-hop-route[Cisco-IOS-XR-ip-rib-ipv6-oper:address = ' + str(self.address) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.address is not None:
                                                        return True

                                                    if self.active is not None:
                                                        return True

                                                    if self.attribute_identity is not None:
                                                        return True

                                                    if self.client_id is not None:
                                                        return True

                                                    if self.distance is not None:
                                                        return True

                                                    if self.diversion is not None:
                                                        return True

                                                    if self.diversion_distance is not None:
                                                        return True

                                                    if self.diversion_proto_name is not None:
                                                        return True

                                                    if self.extended_flags is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.flow_tag is not None:
                                                        return True

                                                    if self.fwd_class is not None:
                                                        return True

                                                    if self.instance is not None:
                                                        return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.paths_count is not None:
                                                        return True

                                                    if self.pic_count is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length_xr is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_name is not None:
                                                        return True

                                                    if self.qos_group is not None:
                                                        return True

                                                    if self.route_age is not None:
                                                        return True

                                                    if self.route_label is not None:
                                                        return True

                                                    if self.route_modify_time is not None:
                                                        return True

                                                    if self.route_path is not None and self.route_path._has_data():
                                                        return True

                                                    if self.route_precedence is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.route_version is not None:
                                                        return True

                                                    if self.svd_type is not None:
                                                        return True

                                                    if self.tag is not None:
                                                        return True

                                                    if self.tbl_version is not None:
                                                        return True

                                                    if self.traffic_index is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:dest-next-hop-routes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dest_next_hop_route is not None:
                                                    for child_ref in self.dest_next_hop_route:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:destination-kw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dest_backup_routes is not None and self.dest_backup_routes._has_data():
                                                return True

                                            if self.dest_best_routes is not None and self.dest_best_routes._has_data():
                                                return True

                                            if self.dest_next_hop_routes is not None and self.dest_next_hop_routes._has_data():
                                                return True

                                            if self.dest_q_routes is not None and self.dest_q_routes._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw']['meta_info']


                                    class Adverts(object):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advert = YList()
                                            self.advert.parent = self
                                            self.advert.name = 'advert'


                                        class Advert(object):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.address = None
                                                self.ipv6_rib_edm_advert = YList()
                                                self.ipv6_rib_edm_advert.parent = self
                                                self.ipv6_rib_edm_advert.name = 'ipv6_rib_edm_advert'
                                                self.prefix_length = None


                                            class Ipv6RibEdmAdvert(object):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.client_id = None
                                                    self.code = None
                                                    self.extended_communities = None
                                                    self.instance_name = None
                                                    self.number_of_extended_communities = None
                                                    self.protocol_id = None
                                                    self.protocol_opaque = None
                                                    self.protocol_opaque_flags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-advert'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.client_id is not None:
                                                        return True

                                                    if self.code is not None:
                                                        return True

                                                    if self.extended_communities is not None:
                                                        return True

                                                    if self.instance_name is not None:
                                                        return True

                                                    if self.number_of_extended_communities is not None:
                                                        return True

                                                    if self.protocol_id is not None:
                                                        return True

                                                    if self.protocol_opaque is not None:
                                                        return True

                                                    if self.protocol_opaque_flags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:advert'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address is not None:
                                                    return True

                                                if self.ipv6_rib_edm_advert is not None:
                                                    for child_ref in self.ipv6_rib_edm_advert:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:adverts'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advert is not None:
                                                for child_ref in self.advert:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts']['meta_info']


                                    class DeletedRoutes(object):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.deleted_route = YList()
                                            self.deleted_route.parent = self
                                            self.deleted_route.name = 'deleted_route'


                                        class DeletedRoute(object):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:deleted-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:deleted-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.deleted_route is not None:
                                                for child_ref in self.deleted_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes']['meta_info']


                                    class Protocol(object):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self.connected = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self.eigrp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self.isis = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self.local = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self.mobile = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self.ospf = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self.rpl = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self.static = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self.subscriber = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self.te_client = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self


                                        class Local(object):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lspv = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self


                                            class Lspv(object):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:lspv'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv']['meta_info']


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lspv is not None and self.lspv._has_data():
                                                    return True

                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local']['meta_info']


                                        class Bgp(object):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:bgp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp']['meta_info']


                                        class Mobile(object):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:mobile'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile']['meta_info']


                                        class Eigrp(object):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:eigrp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp']['meta_info']


                                        class Rpl(object):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:rpl'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl']['meta_info']


                                        class Static(object):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:static'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static']['meta_info']


                                        class TeClient(object):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:te-client'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient']['meta_info']


                                        class Subscriber(object):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:subscriber'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber']['meta_info']


                                        class Ospf(object):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ospf'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf']['meta_info']


                                        class Connected(object):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:   :py:class:`L2Vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                self.l2vpn.parent = self
                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self


                                            class L2Vpn(object):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:l2vpn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn']['meta_info']


                                            class NonAs(object):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:non-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:connected'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn is not None and self.l2vpn._has_data():
                                                    return True

                                                if self.non_as is not None and self.non_as._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected']['meta_info']


                                        class Isis(object):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.as_ = YList()
                                                self.as_.parent = self
                                                self.as_.name = 'as_'


                                            class As_(object):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.as_ = None
                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self


                                                class Information(object):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.active_routes_count = None
                                                        self.backup_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.instance = None
                                                        self.paths_count = None
                                                        self.protocol_clients_count = None
                                                        self.protocol_names = None
                                                        self.protocol_route_memory = None
                                                        self.redistribution_client_count = None
                                                        self.routes_counts = None
                                                        self.version = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.active_routes_count is not None:
                                                            return True

                                                        if self.backup_routes_count is not None:
                                                            return True

                                                        if self.deleted_routes_count is not None:
                                                            return True

                                                        if self.instance is not None:
                                                            return True

                                                        if self.paths_count is not None:
                                                            return True

                                                        if self.protocol_clients_count is not None:
                                                            return True

                                                        if self.protocol_names is not None:
                                                            return True

                                                        if self.protocol_route_memory is not None:
                                                            return True

                                                        if self.redistribution_client_count is not None:
                                                            return True

                                                        if self.routes_counts is not None:
                                                            return True

                                                        if self.version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information']['meta_info']


                                                class ProtocolRoutes(object):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.protocol_route = YList()
                                                        self.protocol_route.parent = self
                                                        self.protocol_route.name = 'protocol_route'


                                                    class ProtocolRoute(object):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.active = None
                                                            self.address = None
                                                            self.attribute_identity = None
                                                            self.client_id = None
                                                            self.distance = None
                                                            self.diversion = None
                                                            self.diversion_distance = None
                                                            self.diversion_proto_name = None
                                                            self.extended_flags = None
                                                            self.flags = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.instance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.pic_count = None
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self.prefix_length_xr = None
                                                            self.priority = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.qos_group = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.route_modify_time = None
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self.route_precedence = None
                                                            self.route_type = None
                                                            self.route_version = None
                                                            self.svd_type = None
                                                            self.tag = None
                                                            self.tbl_version = None
                                                            self.traffic_index = None
                                                            self.version = None


                                                        class RoutePath(object):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_rib_edm_path = YList()
                                                                self.ipv6_rib_edm_path.parent = self
                                                                self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                            class Ipv6RibEdmPath(object):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.address = None
                                                                    self.backup_pathid = None
                                                                    self.binding_label = None
                                                                    self.flags = None
                                                                    self.flags64 = None
                                                                    self.has_labelstk = None
                                                                    self.information_source = None
                                                                    self.interface_name = None
                                                                    self.labelstk = YLeafList()
                                                                    self.labelstk.parent = self
                                                                    self.labelstk.name = 'labelstk'
                                                                    self.load_metric = None
                                                                    self.looped = None
                                                                    self.metric = None
                                                                    self.mpls_feid = None
                                                                    self.mvpn_present = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.next_hop_safi = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.nhid_feid = None
                                                                    self.num_labels = None
                                                                    self.number_of_extended_communities = None
                                                                    self.ospf_area_id = None
                                                                    self.path_rt_present = None
                                                                    self.pathid = None
                                                                    self.private_flags = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.remote_backup_addr = YLeafList()
                                                                    self.remote_backup_addr.parent = self
                                                                    self.remote_backup_addr.name = 'remote_backup_addr'
                                                                    self.route_label = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.tunnel_id = None
                                                                    self.v6_information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.vrf_import_rt_present = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.address is not None:
                                                                        return True

                                                                    if self.backup_pathid is not None:
                                                                        return True

                                                                    if self.binding_label is not None:
                                                                        return True

                                                                    if self.flags is not None:
                                                                        return True

                                                                    if self.flags64 is not None:
                                                                        return True

                                                                    if self.has_labelstk is not None:
                                                                        return True

                                                                    if self.information_source is not None:
                                                                        return True

                                                                    if self.interface_name is not None:
                                                                        return True

                                                                    if self.labelstk is not None:
                                                                        for child in self.labelstk:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.load_metric is not None:
                                                                        return True

                                                                    if self.looped is not None:
                                                                        return True

                                                                    if self.metric is not None:
                                                                        return True

                                                                    if self.mpls_feid is not None:
                                                                        return True

                                                                    if self.mvpn_present is not None:
                                                                        return True

                                                                    if self.next_hop_afi is not None:
                                                                        return True

                                                                    if self.next_hop_id is not None:
                                                                        return True

                                                                    if self.next_hop_id_refcount is not None:
                                                                        return True

                                                                    if self.next_hop_safi is not None:
                                                                        return True

                                                                    if self.next_hop_table_id is not None:
                                                                        return True

                                                                    if self.next_hop_table_name is not None:
                                                                        return True

                                                                    if self.next_hop_vrf_name is not None:
                                                                        return True

                                                                    if self.nhid_feid is not None:
                                                                        return True

                                                                    if self.num_labels is not None:
                                                                        return True

                                                                    if self.number_of_extended_communities is not None:
                                                                        return True

                                                                    if self.ospf_area_id is not None:
                                                                        return True

                                                                    if self.path_rt_present is not None:
                                                                        return True

                                                                    if self.pathid is not None:
                                                                        return True

                                                                    if self.private_flags is not None:
                                                                        return True

                                                                    if self.ref_cnt_of_backup is not None:
                                                                        return True

                                                                    if self.remote_backup_addr is not None:
                                                                        for child in self.remote_backup_addr:
                                                                            if child is not None:
                                                                                return True

                                                                    if self.route_label is not None:
                                                                        return True

                                                                    if self.segmented_nexthop_present is not None:
                                                                        return True

                                                                    if self.source_asrt_present is not None:
                                                                        return True

                                                                    if self.source_rd_present is not None:
                                                                        return True

                                                                    if self.tunnel_id is not None:
                                                                        return True

                                                                    if self.v6_information_source is not None:
                                                                        return True

                                                                    if self.v6_nexthop is not None:
                                                                        return True

                                                                    if self.vrf_import_rt_present is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_rib_edm_path is not None:
                                                                    for child_ref in self.ipv6_rib_edm_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.active is not None:
                                                                return True

                                                            if self.address is not None:
                                                                return True

                                                            if self.attribute_identity is not None:
                                                                return True

                                                            if self.client_id is not None:
                                                                return True

                                                            if self.distance is not None:
                                                                return True

                                                            if self.diversion is not None:
                                                                return True

                                                            if self.diversion_distance is not None:
                                                                return True

                                                            if self.diversion_proto_name is not None:
                                                                return True

                                                            if self.extended_flags is not None:
                                                                return True

                                                            if self.flags is not None:
                                                                return True

                                                            if self.flow_tag is not None:
                                                                return True

                                                            if self.fwd_class is not None:
                                                                return True

                                                            if self.instance is not None:
                                                                return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.paths_count is not None:
                                                                return True

                                                            if self.pic_count is not None:
                                                                return True

                                                            if self.prefix is not None:
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            if self.prefix_length_xr is not None:
                                                                return True

                                                            if self.priority is not None:
                                                                return True

                                                            if self.protocol_id is not None:
                                                                return True

                                                            if self.protocol_name is not None:
                                                                return True

                                                            if self.qos_group is not None:
                                                                return True

                                                            if self.route_age is not None:
                                                                return True

                                                            if self.route_label is not None:
                                                                return True

                                                            if self.route_modify_time is not None:
                                                                return True

                                                            if self.route_path is not None and self.route_path._has_data():
                                                                return True

                                                            if self.route_precedence is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.route_version is not None:
                                                                return True

                                                            if self.svd_type is not None:
                                                                return True

                                                            if self.tag is not None:
                                                                return True

                                                            if self.tbl_version is not None:
                                                                return True

                                                            if self.traffic_index is not None:
                                                                return True

                                                            if self.version is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol-routes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.protocol_route is not None:
                                                            for child_ref in self.protocol_route:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.as_ is None:
                                                        raise YPYModelError('Key property as_ is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:as[Cisco-IOS-XR-ip-rib-ipv6-oper:as = ' + str(self.as_) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.as_ is not None:
                                                        return True

                                                    if self.information is not None and self.information._has_data():
                                                        return True

                                                    if self.protocol_routes is not None and self.protocol_routes._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:isis'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.as_ is not None:
                                                    for child_ref in self.as_:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:protocol'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp is not None and self.bgp._has_data():
                                                return True

                                            if self.connected is not None and self.connected._has_data():
                                                return True

                                            if self.eigrp is not None and self.eigrp._has_data():
                                                return True

                                            if self.isis is not None and self.isis._has_data():
                                                return True

                                            if self.local is not None and self.local._has_data():
                                                return True

                                            if self.mobile is not None and self.mobile._has_data():
                                                return True

                                            if self.ospf is not None and self.ospf._has_data():
                                                return True

                                            if self.rpl is not None and self.rpl._has_data():
                                                return True

                                            if self.static is not None and self.static._has_data():
                                                return True

                                            if self.subscriber is not None and self.subscriber._has_data():
                                                return True

                                            if self.te_client is not None and self.te_client._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol']['meta_info']


                                    class Routes(object):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.route = YList()
                                            self.route.parent = self
                                            self.route.name = 'route'


                                        class Route(object):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.interface_name = None
                                                self.metric = None
                                                self.next_hop_address = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.interface_name is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.next_hop_address is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.route is not None:
                                                for child_ref in self.route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes']['meta_info']


                                    class QRoutes(object):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.q_route = YList()
                                            self.q_route.parent = self
                                            self.q_route.name = 'q_route'


                                        class QRoute(object):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:q-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:q-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.q_route is not None:
                                                for child_ref in self.q_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes']['meta_info']


                                    class BackupRoutes(object):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.backup_route = YList()
                                            self.backup_route.parent = self
                                            self.backup_route.name = 'backup_route'


                                        class BackupRoute(object):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.active = None
                                                self.address = None
                                                self.attribute_identity = None
                                                self.client_id = None
                                                self.distance = None
                                                self.diversion = None
                                                self.diversion_distance = None
                                                self.diversion_proto_name = None
                                                self.extended_flags = None
                                                self.flags = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.instance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.pic_count = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.prefix_length_xr = None
                                                self.priority = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.protoid = None
                                                self.qos_group = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.route_modify_time = None
                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self.route_precedence = None
                                                self.route_type = None
                                                self.route_version = None
                                                self.svd_type = None
                                                self.tag = None
                                                self.tbl_version = None
                                                self.traffic_index = None
                                                self.version = None


                                            class RoutePath(object):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_rib_edm_path = YList()
                                                    self.ipv6_rib_edm_path.parent = self
                                                    self.ipv6_rib_edm_path.name = 'ipv6_rib_edm_path'


                                                class Ipv6RibEdmPath(object):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.address = None
                                                        self.backup_pathid = None
                                                        self.binding_label = None
                                                        self.flags = None
                                                        self.flags64 = None
                                                        self.has_labelstk = None
                                                        self.information_source = None
                                                        self.interface_name = None
                                                        self.labelstk = YLeafList()
                                                        self.labelstk.parent = self
                                                        self.labelstk.name = 'labelstk'
                                                        self.load_metric = None
                                                        self.looped = None
                                                        self.metric = None
                                                        self.mpls_feid = None
                                                        self.mvpn_present = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.next_hop_safi = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_vrf_name = None
                                                        self.nhid_feid = None
                                                        self.num_labels = None
                                                        self.number_of_extended_communities = None
                                                        self.ospf_area_id = None
                                                        self.path_rt_present = None
                                                        self.pathid = None
                                                        self.private_flags = None
                                                        self.ref_cnt_of_backup = None
                                                        self.remote_backup_addr = YLeafList()
                                                        self.remote_backup_addr.parent = self
                                                        self.remote_backup_addr.name = 'remote_backup_addr'
                                                        self.route_label = None
                                                        self.segmented_nexthop_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.tunnel_id = None
                                                        self.v6_information_source = None
                                                        self.v6_nexthop = None
                                                        self.vrf_import_rt_present = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-edm-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.address is not None:
                                                            return True

                                                        if self.backup_pathid is not None:
                                                            return True

                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.flags is not None:
                                                            return True

                                                        if self.flags64 is not None:
                                                            return True

                                                        if self.has_labelstk is not None:
                                                            return True

                                                        if self.information_source is not None:
                                                            return True

                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.labelstk is not None:
                                                            for child in self.labelstk:
                                                                if child is not None:
                                                                    return True

                                                        if self.load_metric is not None:
                                                            return True

                                                        if self.looped is not None:
                                                            return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.mpls_feid is not None:
                                                            return True

                                                        if self.mvpn_present is not None:
                                                            return True

                                                        if self.next_hop_afi is not None:
                                                            return True

                                                        if self.next_hop_id is not None:
                                                            return True

                                                        if self.next_hop_id_refcount is not None:
                                                            return True

                                                        if self.next_hop_safi is not None:
                                                            return True

                                                        if self.next_hop_table_id is not None:
                                                            return True

                                                        if self.next_hop_table_name is not None:
                                                            return True

                                                        if self.next_hop_vrf_name is not None:
                                                            return True

                                                        if self.nhid_feid is not None:
                                                            return True

                                                        if self.num_labels is not None:
                                                            return True

                                                        if self.number_of_extended_communities is not None:
                                                            return True

                                                        if self.ospf_area_id is not None:
                                                            return True

                                                        if self.path_rt_present is not None:
                                                            return True

                                                        if self.pathid is not None:
                                                            return True

                                                        if self.private_flags is not None:
                                                            return True

                                                        if self.ref_cnt_of_backup is not None:
                                                            return True

                                                        if self.remote_backup_addr is not None:
                                                            for child in self.remote_backup_addr:
                                                                if child is not None:
                                                                    return True

                                                        if self.route_label is not None:
                                                            return True

                                                        if self.segmented_nexthop_present is not None:
                                                            return True

                                                        if self.source_asrt_present is not None:
                                                            return True

                                                        if self.source_rd_present is not None:
                                                            return True

                                                        if self.tunnel_id is not None:
                                                            return True

                                                        if self.v6_information_source is not None:
                                                            return True

                                                        if self.v6_nexthop is not None:
                                                            return True

                                                        if self.vrf_import_rt_present is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:route-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_rib_edm_path is not None:
                                                        for child_ref in self.ipv6_rib_edm_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:backup-route'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active is not None:
                                                    return True

                                                if self.address is not None:
                                                    return True

                                                if self.attribute_identity is not None:
                                                    return True

                                                if self.client_id is not None:
                                                    return True

                                                if self.distance is not None:
                                                    return True

                                                if self.diversion is not None:
                                                    return True

                                                if self.diversion_distance is not None:
                                                    return True

                                                if self.diversion_proto_name is not None:
                                                    return True

                                                if self.extended_flags is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.flow_tag is not None:
                                                    return True

                                                if self.fwd_class is not None:
                                                    return True

                                                if self.instance is not None:
                                                    return True

                                                if self.metric is not None:
                                                    return True

                                                if self.paths_count is not None:
                                                    return True

                                                if self.pic_count is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.prefix_length_xr is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.protocol_id is not None:
                                                    return True

                                                if self.protocol_name is not None:
                                                    return True

                                                if self.protoid is not None:
                                                    return True

                                                if self.qos_group is not None:
                                                    return True

                                                if self.route_age is not None:
                                                    return True

                                                if self.route_label is not None:
                                                    return True

                                                if self.route_modify_time is not None:
                                                    return True

                                                if self.route_path is not None and self.route_path._has_data():
                                                    return True

                                                if self.route_precedence is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.route_version is not None:
                                                    return True

                                                if self.svd_type is not None:
                                                    return True

                                                if self.tag is not None:
                                                    return True

                                                if self.tbl_version is not None:
                                                    return True

                                                if self.traffic_index is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:backup-routes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.backup_route is not None:
                                                for child_ref in self.backup_route:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.route_table_name is None:
                                            raise YPYModelError('Key property route_table_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ip-rib-route-table-name[Cisco-IOS-XR-ip-rib-ipv6-oper:route-table-name = ' + str(self.route_table_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.route_table_name is not None:
                                            return True

                                        if self.adverts is not None and self.adverts._has_data():
                                            return True

                                        if self.backup_routes is not None and self.backup_routes._has_data():
                                            return True

                                        if self.deleted_routes is not None and self.deleted_routes._has_data():
                                            return True

                                        if self.destination_kw is not None and self.destination_kw._has_data():
                                            return True

                                        if self.protocol is not None and self.protocol._has_data():
                                            return True

                                        if self.q_routes is not None and self.q_routes._has_data():
                                            return True

                                        if self.routes is not None and self.routes._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:ip-rib-route-table-names'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_rib_route_table_name is not None:
                                        for child_ref in self.ip_rib_route_table_name:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.saf_name is None:
                                    raise YPYModelError('Key property saf_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:saf[Cisco-IOS-XR-ip-rib-ipv6-oper:saf-name = ' + str(self.saf_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.saf_name is not None:
                                    return True

                                if self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:safs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.saf is not None:
                                for child_ref in self.saf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                            return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.af_name is None:
                            raise YPYModelError('Key property af_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:af[Cisco-IOS-XR-ip-rib-ipv6-oper:af-name = ' + str(self.af_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.safs is not None and self.safs._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                        return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs.Af']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ip-rib-ipv6-oper:afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.af is not None:
                        for child_ref in self.af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                    return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf.Afs']['meta_info']

            @property
            def _common_path(self):
                if self.vrf_name is None:
                    raise YPYModelError('Key property vrf_name is None')

                return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/Cisco-IOS-XR-ip-rib-ipv6-oper:vrfs/Cisco-IOS-XR-ip-rib-ipv6-oper:vrf[Cisco-IOS-XR-ip-rib-ipv6-oper:vrf-name = ' + str(self.vrf_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf_name is not None:
                    return True

                if self.afs is not None and self.afs._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
                return meta._meta_table['Ipv6RibStdby.Vrfs.Vrf']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/Cisco-IOS-XR-ip-rib-ipv6-oper:vrfs'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.vrf is not None:
                for child_ref in self.vrf:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
            return meta._meta_table['Ipv6RibStdby.Vrfs']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.rib_table_ids is not None and self.rib_table_ids._has_data():
            return True

        if self.vrfs is not None and self.vrfs._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ip_rib_ipv6_oper as meta
        return meta._meta_table['Ipv6RibStdby']['meta_info']


